@@ -8,9 +8,9 @@ exit_code=0
 check_scope=$1
 if [[ "${check_scope}" = "all" ]]; then
     echo "all"
-    files=($(git ls-files | grep "\.go" | grep -v -e "^third_party" -e "^vendor"))
+    files=($(git ls-files | grep "\.go$" | grep -v -e "^third_party" -e "^vendor"))
 else
-    files=($(git diff --cached --name-only --diff-filter ACM | grep "\.go" | grep -v -e "^third_party" -e "^vendor"))
+    files=($(git diff --cached --name-only --diff-filter ACM | grep "\.go$" | grep -v -e "^third_party" -e "^vendor"))
 fi
 
 echo -e "${green}1. Formatting code style"
@@ -19,13 +19,12 @@ if [[ "${#files[@]}" -ne 0 ]]; then
 fi
 
 echo -e "${green}2. Linting"
-for file in "${files[@]}"; do
-    out=$(golint ${file})
-    if [[ -n "${out}" ]]; then
-        echo "${red}${out}"
-        exit_code=1
-    fi
-done
+out=$(golangci-lint run)
+if [[ -n "${out}" ]]; then
+    echo "${red}${out}"
+    exit_code=1
+fi
+
 
 if [[ ${exit_code} -ne 0 ]]; then
     echo "${red}Please fix the errors above :)"
